/* A Bison parser, made by GNU Bison 2.7.12-4996.  */

/* Bison implementation for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.7.12-4996"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1


/* Substitute the variable and function names.  */
#define yyparse         dvdvmparse
#define yylex           dvdvmlex
#define yyerror         dvdvmerror
#define yylval          dvdvmlval
#define yychar          dvdvmchar
#define yydebug         dvdvmdebug
#define yynerrs         dvdvmnerrs

/* Copy the first part of user declarations.  */
/* Line 371 of yacc.c  */
#line 1 "dvdvmy.y"


/*
 * Copyright (C) 2002 Scott Smith (trckjunky@users.sourceforge.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

#include "compat.h" /* needed for bool */
#include "dvdvm.h"


#define YYERROR_VERBOSE


/* Line 371 of yacc.c  */
#line 104 "dvdvmy.c"

# ifndef YY_NULL
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULL nullptr
#  else
#   define YY_NULL 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* In a future release of Bison, this section will be replaced
   by #include "dvdvmy.h".  */
#ifndef YY_DVDVM_DVDVMY_H_INCLUDED
# define YY_DVDVM_DVDVMY_H_INCLUDED
/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int dvdvmdebug;
#endif

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NUM_TOK = 258,
     G_TOK = 259,
     S_TOK = 260,
     ID_TOK = 261,
     ANGLE_TOK = 262,
     AUDIO_TOK = 263,
     BREAK_TOK = 264,
     BUTTON_TOK = 265,
     CALL_TOK = 266,
     CELL_TOK = 267,
     CHAPTER_TOK = 268,
     CLOSEBRACE_TOK = 269,
     CLOSEPAREN_TOK = 270,
     COUNTER_TOK = 271,
     ELSE_TOK = 272,
     ENTRY_TOK = 273,
     EXIT_TOK = 274,
     FPC_TOK = 275,
     GOTO_TOK = 276,
     IF_TOK = 277,
     JUMP_TOK = 278,
     LAST_TOK = 279,
     MENU_TOK = 280,
     NEXT_TOK = 281,
     OPENBRACE_TOK = 282,
     OPENPAREN_TOK = 283,
     PGC_TOK = 284,
     PREV_TOK = 285,
     PROGRAM_TOK = 286,
     PTT_TOK = 287,
     REGION_TOK = 288,
     RESUME_TOK = 289,
     RND_TOK = 290,
     ROOT_TOK = 291,
     SET_TOK = 292,
     SUBTITLE_TOK = 293,
     TAIL_TOK = 294,
     TITLE_TOK = 295,
     TITLESET_TOK = 296,
     TOP_TOK = 297,
     UP_TOK = 298,
     VMGM_TOK = 299,
     BOR_TOK = 300,
     LOR_TOK = 301,
     XOR_TOK = 302,
     _OR_TOK = 303,
     BAND_TOK = 304,
     LAND_TOK = 305,
     _AND_TOK = 306,
     NOT_TOK = 307,
     NE_TOK = 308,
     EQ_TOK = 309,
     LT_TOK = 310,
     LE_TOK = 311,
     GT_TOK = 312,
     GE_TOK = 313,
     SUB_TOK = 314,
     ADD_TOK = 315,
     MOD_TOK = 316,
     DIV_TOK = 317,
     MUL_TOK = 318,
     ADDSET_TOK = 319,
     SUBSET_TOK = 320,
     MULSET_TOK = 321,
     DIVSET_TOK = 322,
     MODSET_TOK = 323,
     ANDSET_TOK = 324,
     ORSET_TOK = 325,
     XORSET_TOK = 326,
     SEMICOLON_TOK = 327,
     COLON_TOK = 328,
     ERROR_TOK = 329
   };
#endif
/* Tokens.  */
#define NUM_TOK 258
#define G_TOK 259
#define S_TOK 260
#define ID_TOK 261
#define ANGLE_TOK 262
#define AUDIO_TOK 263
#define BREAK_TOK 264
#define BUTTON_TOK 265
#define CALL_TOK 266
#define CELL_TOK 267
#define CHAPTER_TOK 268
#define CLOSEBRACE_TOK 269
#define CLOSEPAREN_TOK 270
#define COUNTER_TOK 271
#define ELSE_TOK 272
#define ENTRY_TOK 273
#define EXIT_TOK 274
#define FPC_TOK 275
#define GOTO_TOK 276
#define IF_TOK 277
#define JUMP_TOK 278
#define LAST_TOK 279
#define MENU_TOK 280
#define NEXT_TOK 281
#define OPENBRACE_TOK 282
#define OPENPAREN_TOK 283
#define PGC_TOK 284
#define PREV_TOK 285
#define PROGRAM_TOK 286
#define PTT_TOK 287
#define REGION_TOK 288
#define RESUME_TOK 289
#define RND_TOK 290
#define ROOT_TOK 291
#define SET_TOK 292
#define SUBTITLE_TOK 293
#define TAIL_TOK 294
#define TITLE_TOK 295
#define TITLESET_TOK 296
#define TOP_TOK 297
#define UP_TOK 298
#define VMGM_TOK 299
#define BOR_TOK 300
#define LOR_TOK 301
#define XOR_TOK 302
#define _OR_TOK 303
#define BAND_TOK 304
#define LAND_TOK 305
#define _AND_TOK 306
#define NOT_TOK 307
#define NE_TOK 308
#define EQ_TOK 309
#define LT_TOK 310
#define LE_TOK 311
#define GT_TOK 312
#define GE_TOK 313
#define SUB_TOK 314
#define ADD_TOK 315
#define MOD_TOK 316
#define DIV_TOK 317
#define MUL_TOK 318
#define ADDSET_TOK 319
#define SUBSET_TOK 320
#define MULSET_TOK 321
#define DIVSET_TOK 322
#define MODSET_TOK 323
#define ANDSET_TOK 324
#define ORSET_TOK 325
#define XORSET_TOK 326
#define SEMICOLON_TOK 327
#define COLON_TOK 328
#define ERROR_TOK 329



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{
/* Line 387 of yacc.c  */
#line 92 "dvdvmy.y"

    unsigned int int_val;
    char *str_val;
    struct vm_statement *statement;


/* Line 387 of yacc.c  */
#line 302 "dvdvmy.c"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE dvdvmlval;

#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int dvdvmparse (void *YYPARSE_PARAM);
#else
int dvdvmparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int dvdvmparse (void);
#else
int dvdvmparse ();
#endif
#endif /* ! YYPARSE_PARAM */

#endif /* !YY_DVDVM_DVDVMY_H_INCLUDED  */

/* Copy the second part of user declarations.  */

/* Line 390 of yacc.c  */
#line 330 "dvdvmy.c"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef __attribute__
/* This feature is available in gcc versions 2.5 and later.  */
# if (! defined __GNUC__ || __GNUC__ < 2 \
      || (__GNUC__ == 2 && __GNUC_MINOR__ < 5))
#  define __attribute__(Spec) /* empty */
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif


/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(N) (N)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int yyi)
#else
static int
YYID (yyi)
    int yyi;
#endif
{
  return yyi;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
	Stack = &yyptr->Stack_alloc;					\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (YYID (0))
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  46
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   387

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  75
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  19
/* YYNRULES -- Number of rules.  */
#define YYNRULES  98
/* YYNRULES -- Number of states.  */
#define YYNSTATES  194

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   329

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     5,     7,    10,    12,    14,    17,    20,
      24,    27,    30,    32,    36,    38,    41,    43,    44,    47,
      49,    53,    57,    61,    65,    69,    73,    75,    78,    79,
      82,    83,    89,    94,    99,   104,   109,   114,   119,   124,
     129,   134,   139,   144,   149,   154,   159,   162,   163,   166,
     167,   175,   177,   179,   181,   183,   185,   187,   189,   191,
     193,   197,   199,   203,   207,   211,   215,   219,   223,   227,
     231,   235,   239,   244,   248,   252,   256,   260,   264,   268,
     272,   276,   280,   284,   288,   291,   293,   296,   301,   306,
     311,   316,   321,   326,   331,   336,   341,   347,   349
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int8 yyrhs[] =
{
      76,     0,    -1,    77,    -1,    78,    -1,    78,    77,    -1,
      82,    -1,    85,    -1,    19,    72,    -1,    34,    72,    -1,
      21,     6,    72,    -1,     6,    73,    -1,     9,    72,    -1,
      91,    -1,    27,    77,    14,    -1,    93,    -1,    41,     3,
      -1,    44,    -1,    -1,    25,     3,    -1,    25,    -1,    25,
      18,    40,    -1,    25,    18,    36,    -1,    25,    18,    38,
      -1,    25,    18,     8,    -1,    25,    18,     7,    -1,    25,
      18,    32,    -1,    20,    -1,    40,     3,    -1,    -1,    13,
       3,    -1,    -1,    23,    79,    80,    81,    72,    -1,    23,
      26,    40,    72,    -1,    23,    12,     3,    72,    -1,    23,
      31,     3,    72,    -1,    23,    12,    42,    72,    -1,    23,
      26,    12,    72,    -1,    23,    30,    12,    72,    -1,    23,
      31,    42,    72,    -1,    23,    26,    31,    72,    -1,    23,
      30,    31,    72,    -1,    23,    29,    42,    72,    -1,    23,
      26,    29,    72,    -1,    23,    30,    29,    72,    -1,    23,
      43,    29,    72,    -1,    23,    29,    39,    72,    -1,    34,
       3,    -1,    -1,    24,    25,    -1,    -1,    11,    79,    80,
      81,    83,    84,    72,    -1,     4,    -1,     5,    -1,     8,
      -1,    38,    -1,     7,    -1,    10,    -1,    33,    -1,    86,
      -1,     3,    -1,    28,    88,    15,    -1,    87,    -1,    88,
      60,    88,    -1,    88,    59,    88,    -1,    88,    63,    88,
      -1,    88,    62,    88,    -1,    88,    61,    88,    -1,    88,
      49,    88,    -1,    88,    45,    88,    -1,    88,    51,    88,
      -1,    88,    48,    88,    -1,    88,    47,    88,    -1,    35,
      28,    88,    15,    -1,    28,    89,    15,    -1,    88,    54,
      88,    -1,    88,    53,    88,    -1,    88,    58,    88,    -1,
      88,    57,    88,    -1,    88,    56,    88,    -1,    88,    55,
      88,    -1,    89,    46,    89,    -1,    89,    50,    89,    -1,
      89,    48,    89,    -1,    89,    51,    89,    -1,    52,    89,
      -1,    86,    -1,    16,     4,    -1,    90,    37,    88,    72,
      -1,    86,    64,    88,    72,    -1,    86,    65,    88,    72,
      -1,    86,    66,    88,    72,    -1,    86,    67,    88,    72,
      -1,    86,    68,    88,    72,    -1,    86,    69,    88,    72,
      -1,    86,    70,    88,    72,    -1,    86,    71,    88,    72,
      -1,    22,    28,    89,    15,    78,    -1,    92,    -1,    92,
      17,    78,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   103,   103,   108,   111,   117,   120,   123,   127,   132,
     137,   142,   146,   149,   152,   157,   160,   163,   168,   171,
     174,   177,   180,   183,   186,   189,   192,   195,   198,   203,
     206,   211,   218,   223,   228,   233,   238,   243,   248,   253,
     258,   263,   268,   273,   278,   283,   290,   293,   298,   301,
     306,   317,   320,   323,   326,   329,   332,   335,   340,   343,
     348,   351,   356,   359,   362,   365,   368,   371,   374,   377,
     380,   383,   386,   393,   396,   399,   402,   405,   408,   411,
     414,   417,   420,   423,   426,   433,   436,   441,   447,   450,
     453,   456,   459,   462,   465,   468,   473,   483,   486
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || 0
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "NUM_TOK", "G_TOK", "S_TOK", "ID_TOK",
  "ANGLE_TOK", "AUDIO_TOK", "BREAK_TOK", "BUTTON_TOK", "CALL_TOK",
  "CELL_TOK", "CHAPTER_TOK", "CLOSEBRACE_TOK", "CLOSEPAREN_TOK",
  "COUNTER_TOK", "ELSE_TOK", "ENTRY_TOK", "EXIT_TOK", "FPC_TOK",
  "GOTO_TOK", "IF_TOK", "JUMP_TOK", "LAST_TOK", "MENU_TOK", "NEXT_TOK",
  "OPENBRACE_TOK", "OPENPAREN_TOK", "PGC_TOK", "PREV_TOK", "PROGRAM_TOK",
  "PTT_TOK", "REGION_TOK", "RESUME_TOK", "RND_TOK", "ROOT_TOK", "SET_TOK",
  "SUBTITLE_TOK", "TAIL_TOK", "TITLE_TOK", "TITLESET_TOK", "TOP_TOK",
  "UP_TOK", "VMGM_TOK", "BOR_TOK", "LOR_TOK", "XOR_TOK", "_OR_TOK",
  "BAND_TOK", "LAND_TOK", "_AND_TOK", "NOT_TOK", "NE_TOK", "EQ_TOK",
  "LT_TOK", "LE_TOK", "GT_TOK", "GE_TOK", "SUB_TOK", "ADD_TOK", "MOD_TOK",
  "DIV_TOK", "MUL_TOK", "ADDSET_TOK", "SUBSET_TOK", "MULSET_TOK",
  "DIVSET_TOK", "MODSET_TOK", "ANDSET_TOK", "ORSET_TOK", "XORSET_TOK",
  "SEMICOLON_TOK", "COLON_TOK", "ERROR_TOK", "$accept", "finalparse",
  "statements", "statement", "jtsl", "jtml", "jcl", "jumpstatement",
  "resumel", "lastmenu", "callstatement", "reg", "regornum", "expression",
  "boolexpr", "regorcounter", "setstatement", "ifstatement",
  "ifelsestatement", YY_NULL
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315,   316,   317,   318,   319,   320,   321,   322,   323,   324,
     325,   326,   327,   328,   329
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    75,    76,    77,    77,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    79,    79,    79,    80,    80,
      80,    80,    80,    80,    80,    80,    80,    80,    80,    81,
      81,    82,    82,    82,    82,    82,    82,    82,    82,    82,
      82,    82,    82,    82,    82,    82,    83,    83,    84,    84,
      85,    86,    86,    86,    86,    86,    86,    86,    87,    87,
      88,    88,    88,    88,    88,    88,    88,    88,    88,    88,
      88,    88,    88,    89,    89,    89,    89,    89,    89,    89,
      89,    89,    89,    89,    89,    90,    90,    91,    91,    91,
      91,    91,    91,    91,    91,    91,    92,    93,    93
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     1,     1,     2,     1,     1,     2,     2,     3,
       2,     2,     1,     3,     1,     2,     1,     0,     2,     1,
       3,     3,     3,     3,     3,     3,     1,     2,     0,     2,
       0,     5,     4,     4,     4,     4,     4,     4,     4,     4,
       4,     4,     4,     4,     4,     4,     2,     0,     2,     0,
       7,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       3,     1,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     4,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     2,     1,     2,     4,     4,     4,
       4,     4,     4,     4,     4,     4,     5,     1,     3
};

/* YYDEFACT[STATE-NAME] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,    51,    52,     0,    55,    53,     0,    56,    17,     0,
       0,     0,     0,    17,     0,    57,     0,    54,     0,     2,
       3,     5,     6,    85,     0,    12,    97,    14,    10,    11,
       0,    16,    28,    86,     7,     0,     0,     0,     0,     0,
       0,     0,     0,    28,     0,     8,     1,     4,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    15,    26,
      19,     0,    30,     9,    59,     0,     0,     0,    58,    61,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,    30,    13,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    98,    18,
       0,    27,     0,    47,     0,     0,     0,    84,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,    33,
      35,    36,    42,    39,    32,    45,    41,    37,    43,    40,
      34,    38,    44,     0,     0,    88,    89,    90,    91,    92,
      93,    94,    95,    87,    24,    23,    25,    21,    22,    20,
      29,     0,    49,    60,    73,     0,    68,    71,    70,    67,
      69,    75,    74,    79,    78,    77,    76,    63,    62,    66,
      65,    64,    96,    80,    82,    81,    83,    31,    46,     0,
       0,    72,    48,    50
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,    18,    19,    20,    32,    62,   103,    21,   162,   190,
      22,    68,    69,    70,    71,    24,    25,    26,    27
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -59
static const yytype_int16 yypact[] =
{
     204,   -59,   -59,   -58,   -59,   -59,   -36,   -59,   -15,    21,
     -34,    34,    15,     1,   204,   -59,   -18,   -59,    56,   -59,
     204,   -59,   -59,   310,    40,   -59,    62,   -59,   -59,   -59,
      77,   -59,    -1,   -59,   -59,    22,    82,     7,    76,    16,
       4,     9,    79,    -1,    92,   -59,   -59,   -59,   169,   169,
     169,   169,   169,   169,   169,   169,   169,   204,   -59,   -59,
      19,   106,   101,   -59,   -59,    82,    91,    82,   -59,   -59,
     305,     2,    49,    53,    55,    64,    86,    88,    89,   111,
     113,   114,   115,   116,   117,   118,   101,   -59,   169,   133,
     185,   205,   224,   231,   250,   257,   276,   283,   -59,   -59,
      90,   -59,   146,   141,    84,    45,   169,   -59,   169,   169,
     169,   169,   169,   169,   169,   169,   169,   169,   169,   169,
     169,   169,   169,   169,   204,    82,    82,    82,    82,   -59,
     -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,
     -59,   -59,   -59,   119,   103,   -59,   -59,   -59,   -59,   -59,
     -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,   -59,
     -59,   195,   175,   -59,   -59,   108,   200,   200,   200,    41,
      41,   324,   324,   324,   324,   324,   324,    50,    50,   -59,
     -59,   -59,   -59,    -4,    -4,   -59,   -59,   -59,   -59,   176,
     128,   -59,   -59,   -59
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
     -59,   -59,    14,   -46,   190,   163,   130,   -59,   -59,   -59,
     -59,     0,   -59,   -47,   -44,   -59,   -59,   -59,   -59
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const yytype_uint8 yytable[] =
{
      23,    89,    90,    91,    92,    93,    94,    95,    96,    97,
      72,    98,    83,    37,    23,    28,    80,   124,   104,    59,
      23,   105,    99,   107,    60,    33,    30,    38,    44,    31,
      39,    40,    41,    81,    47,    82,    29,   100,    34,    61,
      35,   144,    30,    36,    42,    31,   127,   128,   125,    73,
     126,    84,   127,   128,    45,    78,    46,    23,    79,   165,
     164,   166,   167,   168,   169,   170,   171,   172,   173,   174,
     175,   176,   177,   178,   179,   180,   181,    56,   182,    57,
      58,   183,   184,   185,   186,    64,     1,     2,    74,     4,
       5,   125,     7,   126,    63,   127,   128,   154,   155,   163,
     119,   120,   121,   122,   123,    75,    87,    76,    85,   101,
      65,   121,   122,   123,   102,    15,    77,    66,   163,   106,
      17,   129,   156,   191,    23,   130,   157,   131,   158,   108,
     159,   109,   110,   111,    67,   112,   132,   113,   114,   115,
     116,   117,   118,   119,   120,   121,   122,   123,   108,   160,
     109,   110,   111,   108,   112,   109,   110,   111,   133,   112,
     134,   135,   119,   120,   121,   122,   123,   119,   120,   121,
     122,   123,    64,     1,     2,   161,     4,     5,   108,     7,
     109,   110,   111,   136,   112,   137,   138,   139,   140,   141,
     142,   187,   119,   120,   121,   122,   123,    88,   188,   189,
     193,   192,    15,    43,    66,   145,    86,    17,     1,     2,
       3,     4,     5,     6,     7,     8,   143,     0,     0,     0,
       9,     0,     0,    10,     0,    11,    12,    13,     0,     0,
     108,    14,   109,   110,   111,     0,   112,    15,    16,     0,
       0,     0,    17,     0,   119,   120,   121,   122,   123,   111,
     108,   112,   109,   110,   111,     0,   112,   146,     0,   119,
     120,   121,   122,   123,   119,   120,   121,   122,   123,   108,
       0,   109,   110,   111,     0,   112,   108,   147,   109,   110,
     111,     0,   112,   119,   120,   121,   122,   123,     0,     0,
     119,   120,   121,   122,   123,   108,   148,   109,   110,   111,
       0,   112,   108,   149,   109,   110,   111,     0,   112,   119,
     120,   121,   122,   123,     0,     0,   119,   120,   121,   122,
     123,   108,   150,   109,   110,   111,     0,   112,   108,   151,
     109,   110,   111,     0,   112,   119,   120,   121,   122,   123,
       0,     0,   119,   120,   121,   122,   123,     0,   152,     0,
     108,     0,   109,   110,   111,   153,   112,     0,   113,   114,
     115,   116,   117,   118,   119,   120,   121,   122,   123,   108,
       0,   109,     0,   111,    48,    49,    50,    51,    52,    53,
      54,    55,     0,   119,   120,   121,   122,   123
};

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-59)))

#define yytable_value_is_error(Yytable_value) \
  YYID (0)

static const yytype_int16 yycheck[] =
{
       0,    48,    49,    50,    51,    52,    53,    54,    55,    56,
       3,    57,     3,    12,    14,    73,    12,    15,    65,    20,
      20,    65,     3,    67,    25,     4,    41,    26,    14,    44,
      29,    30,    31,    29,    20,    31,    72,    18,    72,    40,
       6,    88,    41,    28,    43,    44,    50,    51,    46,    42,
      48,    42,    50,    51,    72,    39,     0,    57,    42,   106,
      15,   108,   109,   110,   111,   112,   113,   114,   115,   116,
     117,   118,   119,   120,   121,   122,   123,    37,   124,    17,
       3,   125,   126,   127,   128,     3,     4,     5,    12,     7,
       8,    46,    10,    48,    72,    50,    51,     7,     8,    15,
      59,    60,    61,    62,    63,    29,    14,    31,    29,     3,
      28,    61,    62,    63,    13,    33,    40,    35,    15,    28,
      38,    72,    32,    15,   124,    72,    36,    72,    38,    45,
      40,    47,    48,    49,    52,    51,    72,    53,    54,    55,
      56,    57,    58,    59,    60,    61,    62,    63,    45,     3,
      47,    48,    49,    45,    51,    47,    48,    49,    72,    51,
      72,    72,    59,    60,    61,    62,    63,    59,    60,    61,
      62,    63,     3,     4,     5,    34,     7,     8,    45,    10,
      47,    48,    49,    72,    51,    72,    72,    72,    72,    72,
      72,    72,    59,    60,    61,    62,    63,    28,     3,    24,
      72,    25,    33,    13,    35,    72,    43,    38,     4,     5,
       6,     7,     8,     9,    10,    11,    86,    -1,    -1,    -1,
      16,    -1,    -1,    19,    -1,    21,    22,    23,    -1,    -1,
      45,    27,    47,    48,    49,    -1,    51,    33,    34,    -1,
      -1,    -1,    38,    -1,    59,    60,    61,    62,    63,    49,
      45,    51,    47,    48,    49,    -1,    51,    72,    -1,    59,
      60,    61,    62,    63,    59,    60,    61,    62,    63,    45,
      -1,    47,    48,    49,    -1,    51,    45,    72,    47,    48,
      49,    -1,    51,    59,    60,    61,    62,    63,    -1,    -1,
      59,    60,    61,    62,    63,    45,    72,    47,    48,    49,
      -1,    51,    45,    72,    47,    48,    49,    -1,    51,    59,
      60,    61,    62,    63,    -1,    -1,    59,    60,    61,    62,
      63,    45,    72,    47,    48,    49,    -1,    51,    45,    72,
      47,    48,    49,    -1,    51,    59,    60,    61,    62,    63,
      -1,    -1,    59,    60,    61,    62,    63,    -1,    72,    -1,
      45,    -1,    47,    48,    49,    72,    51,    -1,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    45,
      -1,    47,    -1,    49,    64,    65,    66,    67,    68,    69,
      70,    71,    -1,    59,    60,    61,    62,    63
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,     4,     5,     6,     7,     8,     9,    10,    11,    16,
      19,    21,    22,    23,    27,    33,    34,    38,    76,    77,
      78,    82,    85,    86,    90,    91,    92,    93,    73,    72,
      41,    44,    79,     4,    72,     6,    28,    12,    26,    29,
      30,    31,    43,    79,    77,    72,     0,    77,    64,    65,
      66,    67,    68,    69,    70,    71,    37,    17,     3,    20,
      25,    40,    80,    72,     3,    28,    35,    52,    86,    87,
      88,    89,     3,    42,    12,    29,    31,    40,    39,    42,
      12,    29,    31,     3,    42,    29,    80,    14,    28,    88,
      88,    88,    88,    88,    88,    88,    88,    88,    78,     3,
      18,     3,    13,    81,    88,    89,    28,    89,    45,    47,
      48,    49,    51,    53,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    15,    46,    48,    50,    51,    72,
      72,    72,    72,    72,    72,    72,    72,    72,    72,    72,
      72,    72,    72,    81,    88,    72,    72,    72,    72,    72,
      72,    72,    72,    72,     7,     8,    32,    36,    38,    40,
       3,    34,    83,    15,    15,    88,    88,    88,    88,    88,
      88,    88,    88,    88,    88,    88,    88,    88,    88,    88,
      88,    88,    78,    89,    89,    89,    89,    72,     3,    24,
      84,    15,    25,    72
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  However,
   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
   discussed.  */

#define YYFAIL		goto yyerrlab
#if defined YYFAIL
  /* This is here to suppress warnings from the GCC cpp's
     -Wunused-macros.  Normally we don't worry about that warning, but
     some users do, and we want to make it easy for users to remove
     YYFAIL uses, which will produce warnings from Bison 2.5.  */
#endif

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))

/* Error token number */
#define YYTERROR	1
#define YYERRCODE	256


/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */
#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
#else
static void
yy_stack_print (yybottom, yytop)
    yytype_int16 *yybottom;
    yytype_int16 *yytop;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
#else
static void
yy_reduce_print (yyvsp, yyrule)
    YYSTYPE *yyvsp;
    int yyrule;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       		       );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, Rule); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULL;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - Assume YYFAIL is not used.  It's too flawed to consider.  See
       <http://lists.gnu.org/archive/html/bison-patches/2009-12/msg00024.html>
       for details.  YYERROR is fine as it does not invoke this
       function.
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yymsg, yytype, yyvaluep)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  YYUSE (yyvaluep);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YYUSE (yytype);
}




/* The lookahead symbol.  */
int yychar;


#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);

/* Number of syntax errors so far.  */
int yynerrs;


/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void *YYPARSE_PARAM)
#else
int
yyparse (YYPARSE_PARAM)
    void *YYPARSE_PARAM;
#endif
#else /* ! YYPARSE_PARAM */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       `yyss': related to states.
       `yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;

	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),
		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss_alloc, yyss);
	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
/* Line 1787 of yacc.c  */
#line 103 "dvdvmy.y"
    {
    dvd_vm_parsed_cmd=(yyval.statement);
}
    break;

  case 3:
/* Line 1787 of yacc.c  */
#line 108 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 4:
/* Line 1787 of yacc.c  */
#line 111 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (2)].statement);
    (yyval.statement)->next=(yyvsp[(2) - (2)].statement);
}
    break;

  case 5:
/* Line 1787 of yacc.c  */
#line 117 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 6:
/* Line 1787 of yacc.c  */
#line 120 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 7:
/* Line 1787 of yacc.c  */
#line 123 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_EXIT;
}
    break;

  case 8:
/* Line 1787 of yacc.c  */
#line 127 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=16;
}
    break;

  case 9:
/* Line 1787 of yacc.c  */
#line 132 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_GOTO;
    (yyval.statement)->s1=(yyvsp[(2) - (3)].str_val);
}
    break;

  case 10:
/* Line 1787 of yacc.c  */
#line 137 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LABEL;
    (yyval.statement)->s1=(yyvsp[(1) - (2)].str_val);
}
    break;

  case 11:
/* Line 1787 of yacc.c  */
#line 142 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_BREAK;
}
    break;

  case 12:
/* Line 1787 of yacc.c  */
#line 146 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 13:
/* Line 1787 of yacc.c  */
#line 149 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(2) - (3)].statement);
}
    break;

  case 14:
/* Line 1787 of yacc.c  */
#line 152 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 15:
/* Line 1787 of yacc.c  */
#line 157 "dvdvmy.y"
    {
    (yyval.int_val)=((yyvsp[(2) - (2)].int_val))+1;
}
    break;

  case 16:
/* Line 1787 of yacc.c  */
#line 160 "dvdvmy.y"
    {
    (yyval.int_val)=1;
}
    break;

  case 17:
/* Line 1787 of yacc.c  */
#line 163 "dvdvmy.y"
    {
    (yyval.int_val)=0;
}
    break;

  case 18:
/* Line 1787 of yacc.c  */
#line 168 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
}
    break;

  case 19:
/* Line 1787 of yacc.c  */
#line 171 "dvdvmy.y"
    {
    (yyval.int_val)=120; // default entry
}
    break;

  case 20:
/* Line 1787 of yacc.c  */
#line 174 "dvdvmy.y"
    {
    (yyval.int_val)=122;
}
    break;

  case 21:
/* Line 1787 of yacc.c  */
#line 177 "dvdvmy.y"
    {
    (yyval.int_val)=123;
}
    break;

  case 22:
/* Line 1787 of yacc.c  */
#line 180 "dvdvmy.y"
    {
    (yyval.int_val)=124;
}
    break;

  case 23:
/* Line 1787 of yacc.c  */
#line 183 "dvdvmy.y"
    {
    (yyval.int_val)=125;
}
    break;

  case 24:
/* Line 1787 of yacc.c  */
#line 186 "dvdvmy.y"
    {
    (yyval.int_val)=126;
}
    break;

  case 25:
/* Line 1787 of yacc.c  */
#line 189 "dvdvmy.y"
    {
    (yyval.int_val)=127;
}
    break;

  case 26:
/* Line 1787 of yacc.c  */
#line 192 "dvdvmy.y"
    {
    (yyval.int_val)=121;
}
    break;

  case 27:
/* Line 1787 of yacc.c  */
#line 195 "dvdvmy.y"
    {
    (yyval.int_val)=((yyvsp[(2) - (2)].int_val))|128;
}
    break;

  case 28:
/* Line 1787 of yacc.c  */
#line 198 "dvdvmy.y"
    {
    (yyval.int_val)=0;
}
    break;

  case 29:
/* Line 1787 of yacc.c  */
#line 203 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
}
    break;

  case 30:
/* Line 1787 of yacc.c  */
#line 206 "dvdvmy.y"
    {
    (yyval.int_val)=0;
}
    break;

  case 31:
/* Line 1787 of yacc.c  */
#line 211 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_JUMP;
    (yyval.statement)->i1=(yyvsp[(2) - (5)].int_val);
    (yyval.statement)->i2=(yyvsp[(3) - (5)].int_val);
    (yyval.statement)->i3=(yyvsp[(4) - (5)].int_val);
}
    break;

  case 32:
/* Line 1787 of yacc.c  */
#line 218 "dvdvmy.y"
    {  // "jump next title;" will be replaced in DVD::SaveDVDAuthor()
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=20;
}
    break;

  case 33:
/* Line 1787 of yacc.c  */
#line 223 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_JUMP;
    (yyval.statement)->i3=2*65536+(yyvsp[(3) - (4)].int_val);
}
    break;

  case 34:
/* Line 1787 of yacc.c  */
#line 228 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_JUMP;
    (yyval.statement)->i3=65536+(yyvsp[(3) - (4)].int_val);
}
    break;

  case 35:
/* Line 1787 of yacc.c  */
#line 233 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=1;
}
    break;

  case 36:
/* Line 1787 of yacc.c  */
#line 238 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=2;
}
    break;

  case 37:
/* Line 1787 of yacc.c  */
#line 243 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=3;
}
    break;

  case 38:
/* Line 1787 of yacc.c  */
#line 248 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=5;
}
    break;

  case 39:
/* Line 1787 of yacc.c  */
#line 253 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=6;
}
    break;

  case 40:
/* Line 1787 of yacc.c  */
#line 258 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=7;
}
    break;

  case 41:
/* Line 1787 of yacc.c  */
#line 263 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=9;
}
    break;

  case 42:
/* Line 1787 of yacc.c  */
#line 268 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=10;
}
    break;

  case 43:
/* Line 1787 of yacc.c  */
#line 273 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=11;
}
    break;

  case 44:
/* Line 1787 of yacc.c  */
#line 278 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=12;
}
    break;

  case 45:
/* Line 1787 of yacc.c  */
#line 283 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_LINK;
    (yyval.statement)->i1=13;
}
    break;

  case 46:
/* Line 1787 of yacc.c  */
#line 290 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
}
    break;

  case 47:
/* Line 1787 of yacc.c  */
#line 293 "dvdvmy.y"
    {
    (yyval.int_val)=0;
}
    break;

  case 48:
/* Line 1787 of yacc.c  */
#line 298 "dvdvmy.y"
    { // "call last menu;" will be replaced in DVD::SaveDVDAuthor()
    (yyval.int_val)=1;
}
    break;

  case 49:
/* Line 1787 of yacc.c  */
#line 301 "dvdvmy.y"
    {
    (yyval.int_val)=0;
}
    break;

  case 50:
/* Line 1787 of yacc.c  */
#line 306 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_CALL;
    (yyval.statement)->i1=(yyvsp[(2) - (7)].int_val);
    (yyval.statement)->i2=(yyvsp[(3) - (7)].int_val);
    (yyval.statement)->i3=(yyvsp[(4) - (7)].int_val);
    (yyval.statement)->i4=(yyvsp[(5) - (7)].int_val);
    (yyval.statement)->i5=(yyvsp[(6) - (7)].int_val);
}
    break;

  case 51:
/* Line 1787 of yacc.c  */
#line 317 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
}
    break;

  case 52:
/* Line 1787 of yacc.c  */
#line 320 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(1) - (1)].int_val)+0x80;
}
    break;

  case 53:
/* Line 1787 of yacc.c  */
#line 323 "dvdvmy.y"
    {
    (yyval.int_val)=0x81;
}
    break;

  case 54:
/* Line 1787 of yacc.c  */
#line 326 "dvdvmy.y"
    {
    (yyval.int_val)=0x82;
}
    break;

  case 55:
/* Line 1787 of yacc.c  */
#line 329 "dvdvmy.y"
    {
    (yyval.int_val)=0x83;
}
    break;

  case 56:
/* Line 1787 of yacc.c  */
#line 332 "dvdvmy.y"
    {
    (yyval.int_val)=0x88;
}
    break;

  case 57:
/* Line 1787 of yacc.c  */
#line 335 "dvdvmy.y"
    {
    (yyval.int_val)=0x80+20;
}
    break;

  case 58:
/* Line 1787 of yacc.c  */
#line 340 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(1) - (1)].int_val)-256;
}
    break;

  case 59:
/* Line 1787 of yacc.c  */
#line 343 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
}
    break;

  case 60:
/* Line 1787 of yacc.c  */
#line 348 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(2) - (3)].statement);
}
    break;

  case 61:
/* Line 1787 of yacc.c  */
#line 351 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_VAL;
    (yyval.statement)->i1=(yyvsp[(1) - (1)].int_val);
}
    break;

  case 62:
/* Line 1787 of yacc.c  */
#line 356 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_ADD,(yyvsp[(3) - (3)].statement));
}
    break;

  case 63:
/* Line 1787 of yacc.c  */
#line 359 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_SUB,(yyvsp[(3) - (3)].statement));
}
    break;

  case 64:
/* Line 1787 of yacc.c  */
#line 362 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_MUL,(yyvsp[(3) - (3)].statement));
}
    break;

  case 65:
/* Line 1787 of yacc.c  */
#line 365 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_DIV,(yyvsp[(3) - (3)].statement));
}
    break;

  case 66:
/* Line 1787 of yacc.c  */
#line 368 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_MOD,(yyvsp[(3) - (3)].statement));
}
    break;

  case 67:
/* Line 1787 of yacc.c  */
#line 371 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_AND,(yyvsp[(3) - (3)].statement));
}
    break;

  case 68:
/* Line 1787 of yacc.c  */
#line 374 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_OR, (yyvsp[(3) - (3)].statement));
}
    break;

  case 69:
/* Line 1787 of yacc.c  */
#line 377 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_AND,(yyvsp[(3) - (3)].statement));
}
    break;

  case 70:
/* Line 1787 of yacc.c  */
#line 380 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_OR, (yyvsp[(3) - (3)].statement));
}
    break;

  case 71:
/* Line 1787 of yacc.c  */
#line 383 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_XOR,(yyvsp[(3) - (3)].statement));
}
    break;

  case 72:
/* Line 1787 of yacc.c  */
#line 386 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_RND;
    (yyval.statement)->param=(yyvsp[(3) - (4)].statement);
}
    break;

  case 73:
/* Line 1787 of yacc.c  */
#line 393 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(2) - (3)].statement);
}
    break;

  case 74:
/* Line 1787 of yacc.c  */
#line 396 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_EQ,(yyvsp[(3) - (3)].statement));
}
    break;

  case 75:
/* Line 1787 of yacc.c  */
#line 399 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_NE,(yyvsp[(3) - (3)].statement));
}
    break;

  case 76:
/* Line 1787 of yacc.c  */
#line 402 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_GTE,(yyvsp[(3) - (3)].statement));
}
    break;

  case 77:
/* Line 1787 of yacc.c  */
#line 405 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_GT,(yyvsp[(3) - (3)].statement));
}
    break;

  case 78:
/* Line 1787 of yacc.c  */
#line 408 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LTE,(yyvsp[(3) - (3)].statement));
}
    break;

  case 79:
/* Line 1787 of yacc.c  */
#line 411 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LT,(yyvsp[(3) - (3)].statement));
}
    break;

  case 80:
/* Line 1787 of yacc.c  */
#line 414 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LOR,(yyvsp[(3) - (3)].statement));
}
    break;

  case 81:
/* Line 1787 of yacc.c  */
#line 417 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LAND,(yyvsp[(3) - (3)].statement));
}
    break;

  case 82:
/* Line 1787 of yacc.c  */
#line 420 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LOR,(yyvsp[(3) - (3)].statement));
}
    break;

  case 83:
/* Line 1787 of yacc.c  */
#line 423 "dvdvmy.y"
    {
    (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LAND,(yyvsp[(3) - (3)].statement));
}
    break;

  case 84:
/* Line 1787 of yacc.c  */
#line 426 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_NOT;
    (yyval.statement)->param=(yyvsp[(2) - (2)].statement);
}
    break;

  case 85:
/* Line 1787 of yacc.c  */
#line 433 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
}
    break;

  case 86:
/* Line 1787 of yacc.c  */
#line 436 "dvdvmy.y"
    {
    (yyval.int_val)=(yyvsp[(2) - (2)].int_val)+0x20;
}
    break;

  case 87:
/* Line 1787 of yacc.c  */
#line 441 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_SET;
    (yyval.statement)->i1=(yyvsp[(1) - (4)].int_val);
    (yyval.statement)->param=(yyvsp[(3) - (4)].statement);
}
    break;

  case 88:
/* Line 1787 of yacc.c  */
#line 447 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_ADD,(yyvsp[(3) - (4)].statement));
}
    break;

  case 89:
/* Line 1787 of yacc.c  */
#line 450 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_SUB,(yyvsp[(3) - (4)].statement));
}
    break;

  case 90:
/* Line 1787 of yacc.c  */
#line 453 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_MUL,(yyvsp[(3) - (4)].statement));
}
    break;

  case 91:
/* Line 1787 of yacc.c  */
#line 456 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_DIV,(yyvsp[(3) - (4)].statement));
}
    break;

  case 92:
/* Line 1787 of yacc.c  */
#line 459 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_MOD,(yyvsp[(3) - (4)].statement));
}
    break;

  case 93:
/* Line 1787 of yacc.c  */
#line 462 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_AND,(yyvsp[(3) - (4)].statement));
}
    break;

  case 94:
/* Line 1787 of yacc.c  */
#line 465 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_OR,(yyvsp[(3) - (4)].statement));
}
    break;

  case 95:
/* Line 1787 of yacc.c  */
#line 468 "dvdvmy.y"
    {
    (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_XOR,(yyvsp[(3) - (4)].statement));
}
    break;

  case 96:
/* Line 1787 of yacc.c  */
#line 473 "dvdvmy.y"
    {
    (yyval.statement)=statement_new();
    (yyval.statement)->op=VM_IF;
    (yyval.statement)->param=(yyvsp[(3) - (5)].statement);
    (yyvsp[(3) - (5)].statement)->next=statement_new();
    (yyvsp[(3) - (5)].statement)->next->op=VM_IF;
    (yyvsp[(3) - (5)].statement)->next->param=(yyvsp[(5) - (5)].statement);
}
    break;

  case 97:
/* Line 1787 of yacc.c  */
#line 483 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (1)].statement);
}
    break;

  case 98:
/* Line 1787 of yacc.c  */
#line 486 "dvdvmy.y"
    {
    (yyval.statement)=(yyvsp[(1) - (3)].statement);
    (yyval.statement)->param->next->next=(yyvsp[(3) - (3)].statement);
}
    break;


/* Line 1787 of yacc.c  */
#line 2579 "dvdvmy.c"
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;


      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}


